#!/bin/bash
#

# build_ifdh_art.sh <product_dir> <e4|nu:e4> <debug|opt|prof> [tar]

usage()
{
   echo "USAGE: `basename ${0}` <product_dir> <e4|nu:e4> <debug|opt|prof>"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ups()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    export PRODUCTS=${product_dir}:${PRODUCTS}
}

set_qualifiers()
{
 
    if [ -z ${basequal} ]
    then
       echo "ERROR: please specify the qualifiers"
       usage
       exit 1
    fi
    if [ -z ${extraqual} ]
    then
       echo "ERROR: please specify the qualifiers"
       usage
       exit 1
    fi
    fullqual=${basequal}:${extraqual}
    qualdir=`echo ${basequal} | sed -e 's/:/-/g'`-${extraqual}
}

die()
{
  echo "$1"; exit 2
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
basequal=${2}
extraqual=${3}

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=ifdh_art
pkgver=v1_4_1
pkgdotver=`echo ${pkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`

get_this_dir

get_ups

set_qualifiers

blddir=${product_dir}/${package}/${pkgver}/build
builddir=${blddir}/`ups flavor`-${qualdir}
tardir=${product_dir}/${package}/${pkgver}/tar

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------
if [ "${extraqual}" = "opt" ]
then
    extra_opt="-o ${basequal}"
elif [ "${extraqual}" = "debug" ]
then
    extra_opt="-d ${basequal}"
elif [ "${extraqual}" = "prof" ]
then
    extra_opt="-p ${basequal}"
fi

mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   echo "       Something is very wrong"
   exit 1
fi
cd ${blddir}
tar xf ${tardir}/${package}-${pkgver}.tar || die "ERROR: failed to unwind ${tardir}/${package}-${pkgver}.tar"

# start with clean build subdirectories
if [ -d ${builddir} ]
then
   rm -rf ${builddir}
fi

echo "creating  ${builddir}"
mkdir -p ${builddir}
if [ ! -d ${builddir} ]
then
   echo "ERROR: failed to create ${builddir}"
   echo "       Something is very wrong"
   exit 1
fi

cd ${builddir}
source ${blddir}/${package}-${pkgver}/ups/setup_for_development ${extra_opt}
set -x

env CC=gcc CXX=g++ FC=gfortran cmake -DCMAKE_INSTALL_PREFIX=${product_dir} -DCMAKE_BUILD_TYPE=$CETPKG_TYPE $CETPKG_SOURCE
make -j4 || die "ERROR: make failed"
make install || die "ERROR: make install failed"
make package || die "ERROR: make package failed"
mv ${builddir}/${package}-${pkgdotver}*.tar.bz2 ${product_dir}

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -q ${fullqual} -z ${product_dir}

exit 0

